@@ -12,7 +12,7 @@ from .service import (
     CommandHistoryNotFoundError,
 )
 from .fsm import CommandCreateStates, CommandEditStates
-from .defaults import DEFAULT_GLOBAL_COMMANDS
+from .defaults import DEFAULT_GLOBAL_COMMANDS, REMOVED_GLOBAL_COMMAND_NAMES
 
 GLOBAL_COMMAND_SCOPE = "global"
 GLOBAL_COMMAND_PROJECT_SLUG = "__global__"
@@ -39,6 +39,7 @@ __all__ = [
     "CommandCreateStates",
     "CommandEditStates",
     "DEFAULT_GLOBAL_COMMANDS",
+    "REMOVED_GLOBAL_COMMAND_NAMES",
     "GLOBAL_COMMAND_SCOPE",
     "GLOBAL_COMMAND_PROJECT_SLUG",
     "GLOBAL_COMMAND_DB_NAME",
